flutter_architecture_generator library
The main library for the Flutter Architecture Generator CLI tool.
This library exposes the FlutterArchGenRunner which registers all
available commands: init, feature, model, page, widget,
service, repository, bloc, migrate, screen, api, undo,
delete, update, list, doctor, and rename.
Classes
- FlutterArchGenRunner
- The command runner for the Flutter Architecture Generator CLI.
Constants
- packageVersion → const String
- The current version of the Flutter Architecture Generator.